<?php

namespace Litepie\Menu\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litepie\Menu\Models\Menu;


class MenuAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Menu $menu, array $request = [])
    {
        $this->model = $menu;

        $function = Str::camel($action);
        event('litepie.menu.menu.action.' . $action . 'ing', [$menu]);
        $data =  $this->$function($menu, $request);
        event('litepie.menu.menu.action.' . $action . 'ed', [$menu]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Menu $menu, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $menu = $menu->create($attributes);
        return $menu;
    }

    public function update(Menu $menu, array $request)
    {
        $attributes = $request;
        $menu->update($attributes);
        return $menu;
    }

    public function destroy(Menu $menu, array $request)
    {
        $menu->delete();
        return $menu;
    }

    public function copy(Menu $menu, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $menu = $menu->replicate();
            $menu->created_at = Carbon::now();
            $menu->save();
            return $menu;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $menu->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $menu;
    }


}
